<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
'0_langue' => 'portugu&ecirc;s [pt]',
'0_liste' => 'spip-dev@rezo.net',
'0_mainteneur' => 'spip-dev@rezo.net',

// A
'access_interface_graphique' => 'Voltar &agrave; interface gr&aacute;fica completa',
'access_mode_texte' => 'Exibir a interface textual simplificada',
'admin_debug' => 'debug',
'admin_modifier_article' => 'Modificar este artigo',
'admin_modifier_auteur' => 'Modificar este autor',
'admin_modifier_breve' => 'Modificar esta not&iacute;cia',
'admin_modifier_mot' => 'Modificar esta palavra-chave',
'admin_modifier_rubrique' => 'Modificar esta rubrica',
'admin_recalculer' => 'Recompor esta p&aacute;gina',
'afficher_trad' => 'show translations', # NEW
'alerte_maj_impossible' => '<b>Alerta&nbsp;!</b> A actualiza&ccedil;&atilde;o da base SQL para a vers&atilde;o @version@ &eacute;  imposs&iacute;vel, talvez por causa de um problema de direito de modifica&ccedil;&atilde;o na base de dados. Contactar com o seu servi&ccedil;o de hospedagem.', # MODIF
'alerte_modif_info_concourante' => 'ATTENTION : Cette information a &eacute;t&eacute; modifi&eacute; par ailleurs. La valeur actuelle est&nbsp;:', # MODIF
'analyse_xml' => 'An&aacute;lise XML',
'annuler' => 'Cancelar',
'antispam_champ_vide' => 'Please leave this field empty:', # NEW
'articles_recents' => 'Artigos mais recentes',
'avis_archive_incorrect' => 'o ficheiro arquivo n&atilde;o &eacute; um ficheiro SPIP',
'avis_archive_invalide' => 'o ficheiro arquivo n&atilde;o &eacute; v&aacute;lido ',
'avis_attention' => ' ATEN&Ccedil;&Acirc;O!',
'avis_champ_incorrect_type_objet' => 'Nome de campo incorrecto @name@ para objecto de tipo @type@',
'avis_colonne_inexistante' => 'A coluna  @col@ n&atilde;o existe',
'avis_echec_syndication_01' => 'A liga&ccedil;&atilde;o falhou: o backend indicado &eacute; indecifr&aacute;vel ou n&atilde;o prop&otilde;e nenhum artigo. ',
'avis_echec_syndication_02' => 'A liga&ccedil;&atilde;o falhou: imposs&iacute;vel aceder ao  backend deste s&iacute;tio.',
'avis_erreur' => 'Erro: ver mais acima ',
'avis_erreur_connexion' => 'Erro de liga&ccedil;&atilde;o ',
'avis_erreur_cookie' => 'problema de cookie',
'avis_erreur_fonction_contexte' => 'Erro de programa&ccedil;&atilde;o. N&atilde;o se deve chamar esta fun&ccedil;&atilde;o neste contexto.',
'avis_erreur_mysql' => 'Erro SQL', # MODIF
'avis_erreur_sauvegarde' => 'Erro na salvaguarda  (@type@ @id_objet@) !',
'avis_erreur_visiteur' => 'Problem entering the private area', # NEW

// B
'barre_a_accent_grave' => 'Inserir um A mai&uacute;sculo com acento grave',
'barre_aide' => 'Utilize as abreviaturas tipogr&aacute;ficas para enriquecer a sua pagina&ccedil;&atilde;o.',
'barre_e_accent_aigu' => 'Inserir um E mai&uacute;sculo com acento agudo ',
'barre_eo' => 'Inserir um E no O',
'barre_eo_maj' => 'Inserir um E no O mai&uacute;sculo',
'barre_euro' => 'Inserir o s&iacute;mbolo &euro;',
'barre_gras' => '  Escrever em {{negro}}',
'barre_guillemets' => 'Cercar por "aspas" ',
'barre_guillemets_simples' => 'Cercar por "aspas de segundo n&iacute;vel" ',
'barre_intertitre' => 'Transfomar em  {{{intert&iacute;tulo}}} ',
'barre_italic' => 'P&ocirc;r em it&aacute;lico ',
'barre_lien' => 'Transformar em [liga&ccedil;&atilde;o hipertexto->http://...]',
'barre_lien_input' => 'Favor indicar o endere&ccedil;o da sua liga&ccedil;&atilde;o (pode indicar um endere&ccedil;o Web sob a forma  http://www.monsite/com ou simplesmente indicar o n&uacute;mero de um artigo deste s&iacute;tio.) ',
'barre_note' => 'Transformar em  [[Nota de rodap&eacute; ]]',
'barre_paragraphe' => 'Create a paragraph', # NEW
'barre_quote' => '<quote>Citar uma  mensagem</quote>',
'bouton_ajouter_document' => 'ACRESCENTAR UM  DOCUMENTO', # MODIF
'bouton_ajouter_image' => 'ACRESCENTAR UMA IMAGEM', # MODIF
'bouton_ajouter_image_document' => 'Add an image or a document', # NEW
'bouton_changer' => 'Mudar',
'bouton_chercher' => 'Procurar',
'bouton_choisir' => 'Escolher',
'bouton_download' => 'Download', # NEW
'bouton_enregistrer' => 'Gravar',
'bouton_radio_desactiver_messagerie_interne' => 'Desactivar a caixa de correio interno',
'bouton_radio_envoi_annonces' => 'Enviar os an&uacute;ncios editoriais',
'bouton_radio_non_envoi_annonces' => 'N&atilde;o enviar an&uacute;ncios',
'bouton_radio_non_envoi_liste_nouveautes' => 'N&atilde;o enviar a lista das novidades',
'bouton_recharger_page' => 'recarregar esta p&aacute;gina',
'bouton_telecharger' => 'Telecarregar',
'bouton_valider' => 'Validar',

// C
'cal_apresmidi' => 'tarde',
'cal_jour_entier' => 'dia todo',
'cal_matin' => 'manh&atilde;',
'cal_par_jour' => 'calend&aacute;rio por dia',
'cal_par_mois' => 'calend&aacute;rio por m&ecirc;s',
'cal_par_semaine' => 'calend&aacute;rio por semana',
'choix_couleur_interface' => 'cor',
'choix_interface' => 'choice of interface', # NEW
'colonne' => 'Column', # NEW
'confirm_changer_statut' => 'Aten&ccedil;&atilde;o, solicitou a altera&ccedil;&atilde;o do estatuto deste elemento. Deseja continuar?',
'correcte' => 'correct', # NEW

// D
'date_aujourdhui' => 'hoje',
'date_avant_jc' => 'a. J.C.',
'date_dans' => 'entre @delai@',
'date_de_mois_1' => '@j@ de @nommois@',
'date_de_mois_10' => '@j@ de @nommois@',
'date_de_mois_11' => '@j@ de @nommois@',
'date_de_mois_12' => '@j@ de @nommois@',
'date_de_mois_2' => '@j@ de @nommois@',
'date_de_mois_3' => '@j@ de @nommois@',
'date_de_mois_4' => '@j@ de @nommois@',
'date_de_mois_5' => '@j@ de @nommois@',
'date_de_mois_6' => '@j@ de @nommois@',
'date_de_mois_7' => '@j@ de @nommois@',
'date_de_mois_8' => '@j@ de @nommois@',
'date_de_mois_9' => '@j@ de @nommois@',
'date_demain' => 'amanh&atilde;',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ a @heure@',
'date_fmt_jour_mois' => '@jour@ de @nommois@',
'date_fmt_jour_mois_annee' => '@jour@ de @nommois@ de @annee@',
'date_fmt_mois_annee' => '@nommois@ de @annee@',
'date_fmt_nomjour_date' => ' @nomjour@ @date@',
'date_heures' => 'horas',
'date_hier' => 'ontem',
'date_il_y_a' => 'h&aacute; @delai@',
'date_jnum1' => '1',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'domingo',
'date_jour_1_abbr' => 'Sun.', # NEW
'date_jour_1_initiale' => 'S.', # NEW
'date_jour_2' => 'segunda-feira',
'date_jour_2_abbr' => 'Mon.', # NEW
'date_jour_2_initiale' => 'M.', # NEW
'date_jour_3' => 'ter&ccedil;a-feira',
'date_jour_3_abbr' => 'Tue.', # NEW
'date_jour_3_initiale' => 'T.', # NEW
'date_jour_4' => 'quarta-feira',
'date_jour_4_abbr' => 'Wed.', # NEW
'date_jour_4_initiale' => 'W.', # NEW
'date_jour_5' => 'quinta-feira',
'date_jour_5_abbr' => 'Thu.', # NEW
'date_jour_5_initiale' => 'T.', # NEW
'date_jour_6' => 'sexta-feira',
'date_jour_6_abbr' => 'Fri.', # NEW
'date_jour_6_initiale' => 'F.', # NEW
'date_jour_7' => 's&aacute;bado',
'date_jour_7_abbr' => 'Sat.', # NEW
'date_jour_7_initiale' => 'S.', # NEW
'date_jours' => 'dias',
'date_minutes' => 'minutos',
'date_mois' => 'meses',
'date_mois_1' => 'Janeiro',
'date_mois_10' => 'Outubro',
'date_mois_11' => 'Novembro',
'date_mois_12' => 'Dezembro',
'date_mois_2' => 'Fevereiro',
'date_mois_3' => 'Mar&ccedil;o',
'date_mois_4' => 'Abril',
'date_mois_5' => 'Maio',
'date_mois_6' => 'Junho',
'date_mois_7' => 'Julho',
'date_mois_8' => 'Agosto',
'date_mois_9' => 'Setembro',
'date_saison_1' => 'inverno',
'date_saison_2' => 'primavera',
'date_saison_3' => 'ver&atilde;o',
'date_saison_4' => 'outono',
'date_secondes' => 'seconds', # NEW
'date_semaines' => 'semanas',
'date_un_mois' => 'month', # NEW
'date_une_heure' => 'hour', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'second', # NEW
'date_une_semaine' => 'week', # NEW
'dirs_commencer' => 'a fim de come&ccedil;ar realmente a instala&ccedil;&atilde;o',
'dirs_preliminaire' => 'Preliminar : <b>Configurar os direitos de acesso</b>',
'dirs_probleme_droits' => 'Problema de direitos de acesso', # MODIF
'dirs_repertoires_absents' => '<b>Os seguintes direct&oacute;rios n&atilde;o foram encontrados&nbsp;: <ul>@bad_dirs@.</ul> </b>
  <p>&Eacute; prov&aacute;vel que resulte de um problema de m&aacute; coloca&ccedil;&atilde;o de mai&uacute;sculas ou min&uacute;sculas.
  Verifique que as min&uacute;sculas e mai&uacute;sculas destes repert&oacute;rios concordam com o que est&aacute; exibido
 acima; se n&atilde;o for o caso, renomeie os repert&oacute;rios com o seu software FTP de modo a corrigir o erro.
  <p>Terminada esta opera&ccedil;&atilde;o, poder&aacute;</p>', # MODIF
'dirs_repertoires_suivants' => '<b>Os seguintes direct&oacute;rios n&atilde;o est&atilde;o acess&iacute;veis para escrita: <ul>@bad_dirs@.</ul> </b>
  <p>Para corrigir, utilize o seu programa de FTP para configurar os direitos de acesso de cada um
  destes direct&oacute;rios. O procedimento est&aacute; explicado em detalhe no manual de instala&ccedil;&atilde;o.
  <p>Uma vez efectuada esta altera&ccedil;&atilde;o, poder&aacute;', # MODIF
'double_occurrence' => 'Double occurrence', # MODIF

// E
'en_cours' => 'processing', # NEW
'entree_dimensions' => 'Dimens&otilde;es&nbsp;:',
'entree_titre_document' => 'T&iacute;tulo do documento&nbsp;:',
'entree_titre_image' => 'T&iacute;tulo da imagem&nbsp;:',
'envoi_via_le_site' => 'Envio pelo site',
'erreur' => 'Error', # NEW
'erreur_balise_non_fermee' => 'last tag not closed:', # NEW
'erreur_texte' => 'error(s)', # NEW
'etape' => 'Stage', # NEW

// F
'fichier_introuvable' => 'Ficheiro @fichier@ n&atilde;o localizado',
'form_auteur_confirmation' => 'Please confirm your email address', # NEW
'form_auteur_email_modifie' => 'Your email address has been changed.', # NEW
'form_auteur_envoi_mail_confirmation' => 'A confirmation email has been sent to @email@. You need to visit the URL mentioned in this message in order to validate your email address.', # NEW
'form_auteur_mail_confirmation' => 'Hello,

You have asked to change your email address.
To confirm your new address, you need to connect to
the address below. (Otherwise your request will be ignored.):

    @url@
', # NEW
'form_deja_inscrit' => 'J&aacute; est&aacute; inscrito',
'form_email_non_valide' => 'O seu endere&ccedil;o email n&atilde;o &eacute; v&aacute;lido',
'form_forum_access_refuse' => 'Voc&ecirc; j&aacute; n&atilde;o tem acesso a este s&iacute;tio',
'form_forum_bonjour' => 'Bom dia @nom@,',
'form_forum_email_deja_enregistre' => 'Este endere&ccedil;o e-mail j&aacute; est&aacute; registado,pode portanto utilizar a sua palavra-passe habitual',
'form_forum_identifiant_mail' => 'O seu novo identificador acabou de lhe ser enviado por email',
'form_forum_identifiants' => 'Identificadores pessoais',
'form_forum_indiquer_nom_email' => 'Indicar aqui o seu nome e o seu endere&ccedil;o email. O seu identificador pessoal ser-lhe-&aacute; enviado rapidamente por correio electr&oacute;nico.',
'form_forum_login' => 'login:',
'form_forum_message_auto' => '(isto &eacute; uma mensagem autom&aacute;tica)',
'form_forum_pass' => 'palavra-passe',
'form_forum_probleme_mail' => 'Problema de mail&nbsp;:o identificador n&atilde;o pode ser mandado ',
'form_forum_voici1' => 'Estes s&atilde;o os seus dados para poder participar nos f&oacute;runs
 do s&iacute;tio  "@nom_site_spip@" (@adresse_site@):', # MODIF
'form_forum_voici2' => 'Eis os seus identificadores para propor artigos no
 s&iacute;tio "@nom_site_spip@" (@adresse_login@):', # MODIF
'form_indiquer_email' => 'Favor indicar o seu endere&ccedil;o email.',
'form_indiquer_nom' => 'Favor indicar o seu nome.',
'form_indiquer_nom_site' => 'Favor indicar o nome do seu s&iacute;tio.',
'form_pet_adresse_site' => 'Endere&ccedil;o do seu s&iacute;tio',
'form_pet_aucune_signature' => 'Nenhuma assinatura corresponde a este c&oacute;digo...',
'form_pet_confirmation' => 'Favor confirmar a sua assinatura:',
'form_pet_deja_enregistre' => 'Este s&iacute;tio j&aacute; est&aacute; registado',
'form_pet_deja_signe' => 'J&aacute; assinou este texto.',
'form_pet_envoi_mail_confirmation' => 'Um correio electr&oacute;nico acabou de lhe ser enviado. Dever&aacute; visitar o endere&ccedil;o do s&iacute;tio Web mencionado neste correio para validar a sua assinatura', # MODIF
'form_pet_mail_confirmation' => 'Bom dia, 

Pediu para assinar o abaixo assinado :
@titre@.

Forneceu as seguintes informa&ccedil;&otilde;es :
    Nome: @nom_email@
    S&iacute;tio: @nom_site@ - @url_site@


IMPORTANTE...
Para validar a sua assinatura, basta ligar-se ao
 endere&ccedil;o abaixo indicado (caso contr&aacute;rio, o seu pedido ser&aacute; rejeitado) :

    @url@


Obrigado pela sua participa&ccedil;&atilde;o
', # MODIF
'form_pet_message_commentaire' => 'Uma mensagem, um coment&aacute;rio&nbsp;?',
'form_pet_nom_site2' => 'Nome do seu s&iacute;tio Web',
'form_pet_probleme_liens' => 'Please edit your message, taking out all hyperlinks.', # NEW
'form_pet_probleme_technique' => 'Problema t&eacute;cnico, as assinaturas est&atilde;o temporariamente suspensas.',
'form_pet_signature_pasprise' => 'A sua assinatura n&atilde;o est&aacute; tomada em conta.',
'form_pet_signature_validee' => 'A sua assinatura foi validada. Obrigado!',
'form_pet_site_deja_enregistre' => 'Este s&iacute;tio j&aacute; est&aacute; registado',
'form_pet_url_invalide' => 'O URL que indicou n&atilde;o &eacute; v&aacute;lido.',
'form_pet_votre_email' => 'O seu endere&ccedil;o email',
'form_pet_votre_nom' => 'O seu nome ou pseud&oacute;nimo',
'form_pet_votre_site' => 'Se tem um s&iacute;tio Web, pode indic&aacute;-lo a seguir',
'form_prop_confirmer_envoi' => 'Confirmar o envio',
'form_prop_description' => 'Descri&ccedil;&atilde;o/coment&aacute;rio',
'form_prop_enregistre' => 'A sua proposta foi registada, aparecer&aacute; em linha depois da valida&ccedil;&atilde;o pelos respons&aacute;veis deste s&iacute;tio.',
'form_prop_envoyer' => 'Mandar uma mensagem',
'form_prop_indiquer_email' => 'Favor indicar um endere&ccedil;o email v&aacute;lido',
'form_prop_indiquer_nom_site' => 'Favor indicar o nome do s&iacute;tio.',
'form_prop_indiquer_sujet' => 'Favor indicar um assunto',
'form_prop_message_envoye' => 'Mensagem mandada',
'form_prop_nom_site' => 'Nome do s&iacute;tio',
'form_prop_non_enregistre' => 'A sua proposta n&atilde;o foi registada.',
'form_prop_sujet' => 'Assunto',
'form_prop_url_site' => 'Endere&ccedil;o (URL) do s&iacute;tio',
'forum_acces_refuse' => 'J&aacute; n&atilde;o tem acesso a esses f&oacute;runs.',
'forum_attention_dix_caracteres' => '<b>Aten&ccedil;&atilde;o&nbsp;!</b> a sua mensagem cont&eacute;m menos de dez car&aacute;cteres.',
'forum_attention_trois_caracteres' => '<b>Aten&ccedil;&atilde;o&nbsp;!</b> o seu t&iacute;tulo cont&eacute;m menos de tr&ecirc;s car&aacute;cteres.',
'forum_attention_trop_caracteres' => '<b>Warning&nbsp;!</b> your message is too long (@compte@ characters)&nbsp;: to be able to save it, the message should not contain more than @max@ characters.', # NEW
'forum_avez_selectionne' => 'Seleccionou&nbsp;:',
'forum_cliquer_retour' => 'Clicar <a href=\'@retour_forum@\'>ici</a> para continuar.',
'forum_forum' => 'f&oacute;rum',
'forum_info_modere' => 'Este f&oacute;rum est&aacute; moderado a priori&nbsp;: a sua contribui&ccedil;&atilde;o s&oacute; aparecer&aacute; depois de ser validada por um administrador do s&iacute;tio.',
'forum_lien_hyper' => '<b>Link hipertexto</b> (opcional)',
'forum_message_definitif' => 'Mensagem definitiva: mandar para o s&iacute;tio',
'forum_message_trop_long' => 'A sua mensagem &eacute; demasiado comprida. O tamanho m&aacute;ximo &eacute; 20000 car&aacute;cteres.',
'forum_ne_repondez_pas' => 'N&atilde;o responder para este mail mas no f&oacute;rum, para o endere&ccedil;o seguinte:',
'forum_non_inscrit' => 'N&atilde;o est&aacute; inscrito, ou o endere&ccedil;o ou a palavra-passe est&atilde;o errados.',
'forum_page_url' => '(Se a sua mensagem se refere a um artigo publicado na Web, ou a uma p&aacute;gina que fornece mais informa&ccedil;&otilde;es, por favor indique a seguir o t&iacute;tulo da p&aacute;gina e o seu endere&ccedil;o URL.)',
'forum_par_auteur' => 'por @auteur@',
'forum_poste_par' => 'Mensagem posta@parauteur@ depois do seu artigo', # MODIF
'forum_probleme_database' => 'Problema de base de dados, a sua mensagem n&atilde;o foi registada.',
'forum_qui_etes_vous' => '<b>Quem &eacute; voc&ecirc;?</b> (opcional)',
'forum_texte' => 'Texto da sua mensagem:',
'forum_titre' => 'T&iacute;tulo:',
'forum_titre_erreur' => 'Erro...',
'forum_url' => 'URL:',
'forum_valider' => 'Validar a sua escolha',
'forum_voir_avant' => 'Ver esta mensagem antes de mandar',
'forum_votre_email' => 'O seu endere&ccedil;o email:',
'forum_votre_nom' => 'O seu nome (pseud&oacute;nimo):',
'forum_vous_enregistrer' => 'Para participar
 nesse f&oacute;rum, deve estar previamente registado. &Eacute; favor
  indicar a seguir o identificador pessoal que lhe foi
 fornecido. Se n&atilde;o est&aacute; registado, deve  ',
'forum_vous_inscrire' => 'inscrever-se.',

// I
'ical_texte_rss_articles' => 'O ficheiro &laquo;backend&raquo; dos artigos deste s&iacute;tio encontra-se neste endere&ccedil;o:',
'ical_texte_rss_articles2' => 'Pode igualmente obter os ficheiros &laquo;backend&raquo; para os artigos de cada rubrica do s&iacute;tio:',
'ical_texte_rss_breves' => 'Existe tamb&eacute;m um ficheiro contendo not&iacute;cias do s&iacute;tio. Especificando um n&uacute;mero de rubrica, obter&aacute; unicamente as not&iacute;cias dessa rubrica.',
'icone_a_suivre' => 'Continua',
'icone_admin_site' => 'Administra&ccedil;&atilde;o do s&iacute;tio',
'icone_agenda' => 'Agenda e correio',
'icone_aide_ligne' => 'Ajuda',
'icone_articles' => 'Artigos',
'icone_auteurs' => 'Autores',
'icone_breves' => 'Not&iacute;cias',
'icone_brouteur' => 'Navega&ccedil;&atilde;o r&aacute;pida',
'icone_configuration_site' => 'Configura&ccedil;&atilde;o',
'icone_configurer_site' => 'Configurar o seu s&iacute;tio',
'icone_creer_nouvel_auteur' => 'Criar um novo autor',
'icone_creer_rubrique' => 'Criar uma rubrica',
'icone_creer_sous_rubrique' => 'Criar uma sub-rubrica',
'icone_deconnecter' => 'Desligar-se',
'icone_discussions' => 'Discuss&otilde;es',
'icone_doc_rubrique' => 'Documentos das rubricas',
'icone_ecrire_article' => 'Escrever um novo artigo',
'icone_edition_site' => 'Edi&ccedil;&atilde;o',
'icone_forum_administrateur' => 'F&oacute;rum dos administradores',
'icone_forum_suivi' => 'Seguimento dos f&oacute;runs',
'icone_gestion_langues' => 'Gest&atilde;o das l&iacute;nguas',
'icone_informations_personnelles' => 'Informa&ccedil;&otilde;es pessoais',
'icone_interface_complet' => 'interface completa',
'icone_interface_simple' => 'Interface simplificada',
'icone_maintenance_site' => 'Manuten&ccedil;&atilde;o do s&iacute;tio',
'icone_messagerie_personnelle' => 'Correio pessoal',
'icone_mots_cles' => 'Palavras-chave',
'icone_nouvelle_breve' => 'Escrever uma not&iacute;cia curta',
'icone_repartition_actuelle' => 'Exibir a distribui&ccedil;&atilde;o actual',
'icone_repartition_debut' => 'Exibir a distribui&ccedil;&atilde;o desde o in&iacute;cio',
'icone_repartition_visites' => 'Distribui&ccedil;&atilde;o das visitas',
'icone_rubriques' => 'Rubricas',
'icone_sauver_site' => 'Salvaguarda do s&iacute;tio',
'icone_site_entier' => 'Todo o s&iacute;tio',
'icone_sites_references' => 'S&iacute;tios referenciados',
'icone_statistiques' => 'Estat&iacute;sticas do s&iacute;tio',
'icone_statistiques_visites' => 'Estat&iacute;sticas de visitas',
'icone_suivi_activite' => 'Acompanhar a vida do s&iacute;tio',
'icone_suivi_actualite' => 'Evolu&ccedil;&atilde;o do&nbsp;s&iacute;tio',
'icone_suivi_forums' => 'Seguir/gerir os f&oacute;runs',
'icone_suivi_pettions' => 'Seguir/gerir os abaixo-assinados',
'icone_suivi_revisions' => 'Modifica&ccedil;&otilde;es dos artigos',
'icone_supprimer_document' => 'Suprimir este documento',
'icone_supprimer_image' => 'Suprimir esta imagem',
'icone_supprimer_message' => 'Suprimir esta mensagem',
'icone_tous_articles' => 'Todos os seus artigos',
'icone_tous_auteur' => 'Todos os autores',
'icone_valider_message' => 'Validar esta mensagem',
'icone_visiter_site' => 'Visitar',
'icone_voir_en_ligne' => 'Ver em linha',
'image_tourner_180' => 'Rodar 180&deg;',
'image_tourner_droite' => 'Rodar 90&deg; &agrave; direita',
'image_tourner_gauche' => 'Rodar 90&deg; &agrave; esquerda',
'img_indisponible' => 'imagem indispon&iacute;vel',
'impossible' => 'impossible', # NEW
'info_a_suivre' => 'A SEGUIR&nbsp;&raquo;',
'info_a_valider' => '[a validar]',
'info_acces_interdit' => 'Acesso proibido',
'info_acces_refuse' => 'Acesso recusado',
'info_action' => 'Ac&ccedil;&atilde;o : @action@',
'info_administrer_rubriques' => 'Pode administrar esta rubrica e as suas sub-rubricas',
'info_adresse_non_indiquee' => 'N&atilde;o indicou endere&ccedil;o a testar&nbsp;!',
'info_aide' => 'AJUDA',
'info_ajouter_mot' => 'Acrescentar esta palavra',
'info_annonce' => 'AN&Uacute;NCIO',
'info_annonces_generales' => 'An&uacute;ncios gerais&nbsp;:',
'info_article_propose' => 'Artigo proposto',
'info_article_publie' => 'Artigo publicado',
'info_article_redaction' => 'Artigo em curso de redac&ccedil;&atilde;o',
'info_article_refuse' => 'Artigo recusado',
'info_article_supprime' => 'Artigo suprimido',
'info_articles' => 'Artigos',
'info_articles_a_valider' => 'Os artigos a validar',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Artigos propostos',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'autor(es)&nbsp;:',
'info_authentification_ftp' => 'Autentica&ccedil;&atilde;o (por FTP)',
'info_bloquer_lien' => 'bloquear este v&iacute;nculo',
'info_breves_02' => 'Not&iacute;cias',
'info_breves_2' => 'not&iacute;cias',
'info_breves_nb' => '@nb@ news items', # NEW
'info_breves_un' => '1 news item', # NEW
'info_breves_valider' => 'Not&iacute;cias a validar',
'info_connexion_refusee' => 'Liga&ccedil;&atilde;o recusada',
'info_contact_developpeur' => 'Favor contactar com um programador',
'info_contenance' => 'Este s&iacute;tio contem&nbsp;:',
'info_contribution' => 'contribui&ccedil;&otilde;es de f&oacute;rum',
'info_copyright' => '@spip@ &eacute; um software livre distribu&iacute;do @lien_gpl@.',
'info_copyright_doc' => 'Para mais informa&ccedil;&otilde;es, ver o s&iacute;tio <a href="@spipnet@">http://www.spip.net/pt</a>.', # MODIF
'info_copyright_gpl' => 'sob licen&ccedil;a GPL',
'info_cours_edition' => 'Os seus artigos em curso de redac&ccedil;&atilde;o',
'info_creer_repertoire' => 'Favor criar um ficheiro ou um repert&oacute;rio chamado&nbsp;:',
'info_creer_repertoire_2' => 'dentro do sub-repert&oacute;rio <b>@repertoire@</b>, depois&nbsp;:', # MODIF
'info_creer_vignette' => 'cria&ccedil;&atilde;o autom&aacute;tica do &iacute;cone',
'info_deplier' => 'Desenvolver',
'info_descriptif_nombre' => 'descritivo(s)&nbsp;:',
'info_description' => 'Descri&ccedil;&atilde;o&nbsp;:',
'info_description_2' => 'Descri&ccedil;&atilde;o&nbsp;:',
'info_dimension' => 'Dimens&otilde;es&nbsp;:',
'info_document' => 'Documento',
'info_document_indisponible' => 'This document is unavailable', # NEW
'info_documents' => 'Documentos',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP permite a troca de mensagens e a constitui&ccedil;&atilde;o de f&oacute;runs privados de discuss&atilde;o
entre os participantes do s&iacute;tio. Pode activar ou
 desactivar esta funcionalidade.',
'info_ecire_message_prive' => 'Escrever uma mensagem privada',
'info_email_invalide' => 'Endere&ccedil;o email inv&aacute;lido.',
'info_en_cours_validation' => 'Os seus artigos em curso de reda&ccedil;&atilde;o',
'info_en_ligne' => 'Actualmente em linha&nbsp;:',
'info_envoyer_message_prive' => 'Enviar uma mensagem privada a este autor',
'info_erreur_requete' => 'Erro no pedido :',
'info_erreur_squelette2' => 'Template <b>@fichier@</b> n&atilde;o dispon&iacute;vel...',
'info_erreur_systeme' => 'Erro de Sistema (errno @errsys@)',
'info_erreur_systeme2' => 'O disco r&iacute;gido poder&aacute; estar cheio, ou a base de dados danificada. <br />
 <font color=\'red\'>Tente <a href=\'@script@\'>reparar a base</a>,
 ou contacte o seu fornecedor de internet.</font>', # MODIF
'info_fini' => 'Acabou !',
'info_format_image' => 'Formatos de imagens que podem ser utilizadas para criar vinhetas&nbsp;: @gd_formats@.',
'info_format_non_defini' => 'formato n&atilde;o definido',
'info_grand_ecran' => 'Ecr&atilde; total',
'info_image_aide' => 'AJUDA',
'info_image_process_titre' => 'M&eacute;todo de fabrica&ccedil;ao das vinhetas',
'info_impossible_lire_page' => '<b>Erro !</b> Imposs&iacute;vel ler a p&aacute;gina<tt><html>@test_proxy@</html></tt> atrav&eacute;s do proxy <tt>', # MODIF
'info_inclusion_directe' => 'Inclus&atilde;o directa&nbsp;:',
'info_inclusion_vignette' => 'Inclus&atilde;o da vinheta&nbsp;:',
'info_installation_systeme_publication' => 'Instala&ccedil;&atilde;o do sistema de publica&ccedil;&atilde;o',
'info_installer_documents' => '<MODIF>Pode instalar automaticamente todos os documentos contidos no processo @upload@.',
'info_installer_ftp' => 'Como administrador, pode instalar (por FTP) ficheiros no dossier @upload@ para depois seleccion&aacute;-los directamente aqui.', # MODIF
'info_installer_images' => 'Pode instalar imagens nos formatos JPEG, GIF e PNG.',
'info_installer_images_dossier' => 'Instalar imagens no dossier @upload@ para poder seleccion&aacute;-los aqui.', # MODIF
'info_installer_tous_documents' => 'Instalar todos os documentos',
'info_interface_complete' => 'Interface completa',
'info_interface_simple' => 'Interface simplificada',
'info_joindre_document_article' => 'Pode juntar a este artigo documentos de tipo',
'info_joindre_document_rubrique' => 'Pode acrescentar a esta rubrica documentos de tipo',
'info_joindre_documents_article' => 'Pode juntar ao seu artigo documentos de tipo&nbsp;:',
'info_l_article' => 'o artigo',
'info_la_breve' => 'a not&iacute;cia',
'info_la_rubrique' => 'a rubrica',
'info_langue_principale' => 'L&iacute;ngua principal do s&iacute;tio',
'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pixels',
'info_les_auteurs_1' => 'por @les_auteurs@',
'info_logo_format_interdit' => 'Apenas os &iacute;cones nos formatos @formats@ est&atilde;o autorizados.',
'info_logo_max_poids' => 'Os &iacute;cones devem obrigatoriamente ter menos de @maxi@ (este arquivo tem @actuel@).',
'info_logo_max_taille' => 'Os &iacute;cones devem obrigatoriamente ter menos de @maxi@ (este arquivo tem @actuel@).',
'info_mail_fournisseur' => 'voc&ecirc;@seucorreio.com',
'info_message_2' => 'MENSAGEM',
'info_message_supprime' => 'MENSAGEM SUPRIMIDA',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Data de coloca&ccedil;&atilde;o em linha&nbsp;:',
'info_modification_parametres_securite' => 'modifica&ccedil;&atilde;o dos par&acirc;metros de seguran&ccedil;a',
'info_mois_courant' => 'Durante o m&ecirc;s :',
'info_mot_cle_ajoute' => 'A seguinte palavra-chave foi acrescentada a',
'info_multi_herit' => 'L&iacute;ngua por defeito',
'info_multi_langues_soulignees' => 'As <u>l&iacute;nguas sublinhadas</u> beneficiam de uma tradu&ccedil;&atilde;o de todos os textos da interface. Se seleccionar essas l&iacute;nguas, muitos elementos do s&iacute;tio p&uacute;blico (datas, formul&aacute;rios) ser&atilde;o automaticamente traduzidos. Para as l&iacute;nguas n&atilde;o sublinhadas, esses elementos aparecer&atilde;o na l&iacute;ngua principal do s&iacute;tio.', # MODIF
'info_multilinguisme' => 'Multilinguismo',
'info_nom_non_utilisateurs_connectes' => 'O seu nome n&atilde;o aparece na lista dos utilizadores ligados.',
'info_nom_utilisateurs_connectes' => 'O seu nome aparece na lista dos utilizadores ligados.',
'info_nombre_en_ligne' => 'Actualmente em linha&nbsp;:',
'info_non_resultat' => 'Nenhum resultado para "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'N&atilde;o utiliza o correio interno deste s&iacute;tio.',
'info_nouveau_message' => 'TEM UMA NOVA MENSAGEM',
'info_nouveaux_messages' => 'TEM @total_messages@ NOVAS MENSAGENS',
'info_numero_abbreviation' => '<N&deg;&nbsp;>',
'info_obligatoire' => 'This information is required', # NEW
'info_panne_site_syndique' => 'S&iacute;tio vinculado avariado',
'info_pense_bete' => 'MEMORANDO',
'info_petit_ecran' => 'Ecr&atilde; Pequeno',
'info_petition_close' => 'Petition closed', # NEW
'info_pixels' => 'pixels',
'info_plusieurs_mots_trouves' => 'Muitas palavras-chave encontradas para "@cherche_mot@":',
'info_popularite_5' => 'popularidade&nbsp;:',
'info_portfolio' => 'Portf&oacute;lio',
'info_portfolio_automatique' => 'Portfolio autom&aacute;tico&nbsp;:',
'info_premier_resultat' => '[@debut_limit@ primeiros resultados em @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ primeiros resultados em @total@]',
'info_probleme_grave' => 'problema de',
'info_propose_1' => '[@nom_site_spip@] Prop&otilde;e : @titre@',
'info_propose_2' => 'Artigos propostos
----------------',
'info_propose_3' => 'O artigo "@titre@" &eacute; proposto para publica&ccedil;&atilde;o.',
'info_propose_4' => 'Est&aacute; convidado a vir consult&aacute;-lo e a dar a sua opini&atilde;o',
'info_propose_5' => 'no f&oacute;rum que lhe est&aacute; ligado. Est&aacute; dispon&iacute;vel no endere&ccedil;o:',
'info_publie_01' => 'O artigo "@titre@" foi validado por @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] PUBLICA : @titre@',
'info_publie_2' => 'Artigo publicado
--------------',
'info_rechercher' => 'Procurar',
'info_rechercher_02' => 'Procurar&nbsp;:',
'info_remplacer_vignette' => 'Substituir a vinheta por defeito por um logotipo personalizado&nbsp;:',
'info_retablir_lien' => 'restabelecer este v&iacute;nculo',
'info_retirer_mot' => 'Retirar esta palavra',
'info_retirer_mots' => 'Retirar todas as palavras',
'info_rubriques_nb' => '@nb@ sections', # NEW
'info_rubriques_un' => '1 section', # NEW
'info_sans_titre_2' => 'sem t&iacute;tulo',
'info_selectionner_fichier' => 'Pode seleccionar um ficheiro do dossier @upload@', # MODIF
'info_selectionner_fichier_2' => 'Seleccionar um ficheiro&nbsp;:',
'info_signature_supprimee' => 'Signature deleted', # NEW
'info_signature_supprimee_erreur' => 'Error: this deletion code does not correspond to any signature', # NEW
'info_site_attente' => 'S&iacute;tio Web &agrave; espera de valida&ccedil;&atilde;o',
'info_site_reference' => 'S&iacute;tio referenciado em linha',
'info_site_refuse' => 'S&iacute;tio Web recusado',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Referenciar este s&iacute;tio',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'suprimir a vinheta',
'info_symbole_bleu' => 'O s&iacute;mbolo <b>azul</b> indica um<b>memorando </b>: isto &eacute; uma mensagem para o seu uso pessoal.', # MODIF
'info_symbole_jaune' => 'O s&iacute;mbolo<b>amarelo</b> indica um <b>an&uacute;ncio a todos os redactores</b>&nbsp;: modific&aacute;vel por todos os administradores, e vis&iacute;vel por todos os redactores.', # MODIF
'info_symbole_vert' => 'O s&iacute;mbolo<b>verde</b> indica as <b>mensagens trocadas com outros utilizadores</b> do s&iacute;tio.', # MODIF
'info_syndication' => 'vincula&ccedil;&atilde;o:',
'info_syndication_articles' => 'artigo(s)',
'info_telecharger' => 'Telecarregar do seu computador&nbsp;:',
'info_telecharger_nouveau_logo' => 'Telecarregar um novo logotipo&nbsp;:',
'info_telecharger_ordinateur' => 'Telecarregar do seu computador&nbsp;:',
'info_tous_resultats_enregistres' => '[todos os  resultados est&atilde;o registados]',
'info_tout_afficher' => 'Exibir tudo',
'info_travaux_texte' => 'Este s&iacute;tio n&atilde;o est&aacute; configurado. Volte mais tarde...',
'info_travaux_titre' => 'S&iacute;tio em obras',
'info_trop_resultat' => 'Demasiado resultados para "@cherche_mot@" ; favor afinar a pesquisa.',
'info_utilisation_messagerie_interne' => 'Voc&ecirc; utiliza o correio interno deste s&iacute;tio.',
'info_valider_lien' => 'validar este la&ccedil;o',
'info_verifier_image' => ', favor verificar que as suas imagens foram transferidas correctamente.',
'info_vignette_defaut' => 'Vinheta por defeito',
'info_vignette_personnalisee' => 'Vinheta personalizada',
'info_visite' => 'visita :',
'info_visites' => 'visitas :',
'info_vos_rendez_vous' => 'Os seus futuros encontros',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'Os seus memorandos', # MODIF
'item_breve_proposee' => 'Not&iacute;cia proposta',

// L
'lien_afficher_icones_seuls' => 'Exibir apenas os &iacute;cones',
'lien_afficher_texte_icones' => 'Exibir &iacute;cones e o texto',
'lien_afficher_texte_seul' => 'Exibir apenas o texto',
'lien_liberer' => 'desbloquear',
'lien_liberer_tous' => 'desbloquear estes artigos',
'lien_nouvea_pense_bete' => 'NOVO MEMORANDO',
'lien_nouveau_message' => 'NOVA MENSAGEM',
'lien_nouvelle_annonce' => 'NOVO AN&Uacute;NCIO',
'lien_petitions' => 'ABAIXO-ASSINADO',
'lien_popularite' => 'popularidade&nbsp;: @popularite@%',
'lien_racine_site' => 'RAIZ DO S&Iacute;TIO',
'lien_reessayer' => 'tentar de novo',
'lien_repondre_message' => 'Responder a esta mensagem',
'lien_supprimer' => 'suprimir',
'lien_tout_afficher' => 'Exibir tudo',
'lien_visite_site' => 'visitar este s&iacute;tio',
'lien_visites' => '@visites@&nbsp;visitas',
'lien_voir_auteur' => 'Ver este autor',
'ligne' => 'Line', # NEW
'login' => 'Connection', # NEW
'login_acces_prive' => 'acesso ao espa&ccedil;o privado',
'login_autre_identifiant' => 'ligar-se sob um outro identificador',
'login_cookie_accepte' => 'Favor configurar o seu navegador para que os aceite ( pelo menos para este s&iacute;tio).',
'login_cookie_oblige' => 'Para se identificar de maneira segura neste s&iacute;tio, deve aceitar os cookies.',
'login_deconnexion_ok' => 'Liga&ccedil;&atilde;o terminada.',
'login_erreur_pass' => 'Erro de palavra-passe',
'login_espace_prive' => 'espa&ccedil;o privado',
'login_identifiant_inconnu' => 'O identificador &laquo; @login@ &raquo; &eacute; desconhecido.',
'login_login' => 'Login :',
'login_login2' => 'Login (identificador de conex&atilde;o ao s&iacute;tio)&nbsp;:',
'login_login_pass_incorrect' => '(Login ou palavra-passe incorrecta.)',
'login_motpasseoublie' => 'palavra&nbsp;-&nbsp;passe&nbsp;esquecida&nbsp;?',
'login_non_securise' => 'Aten&ccedil;&atilde;o, este formul&aacute;rio n&atilde;o &eacute; seguro.
 Se n&atilde;o quiser que a sua palavra-passe seja
 interceptada na rede, favor active Javascript
 no seu navegador e',
'login_nouvelle_tentative' => 'Nova tentativa',
'login_par_ici' => 'Voc&ecirc; est&aacute; registado... por aqui....',
'login_pass2' => 'Palavra-passe&nbsp;:',
'login_preferez_refuser' => '<b>Se prefere recusar os cookies</b>, um outro m&eacute;todo de liga&ccedil;&atilde;o (menos seguro) est&aacute; &agrave; sua disposi&ccedil;&atilde;o',
'login_recharger' => 'carregar de novo esta p&aacute;gina ',
'login_rester_identifie' => 'Permanecer identificado durante alguns dias ',
'login_retour_public' => 'Regresso ao s&iacute;tio p&uacute;blico',
'login_retour_site' => 'Regresso ao s&iacute;tio p&uacute;blico',
'login_retoursitepublic' => 'Regresso&nbsp;ao&nbsp;s&iacute;tio&nbsp;p&uacute;blico',
'login_sans_cookiie' => 'identifica&ccedil;&atilde;o sem cookie',
'login_securise' => 'Secured login', # NEW
'login_sinscrire' => 'inscrever-se',
'login_test_navigateur' => 'teste navega&ccedil;&atilde;o/nova liga&ccedil;&atilde;o',
'login_verifiez_navigateur' => '(Verifique, por&eacute;m, que o seu navegador n&atilde;o memorizou a sua palavra-passe...)',

// M
'masquer_colonne' => 'Hide this column', # NEW
'masquer_trad' => 'hide translations', # NEW
'module_fichiers_langues' => 'Ficheiros de l&iacute;ngua',

// N
'navigateur_pas_redirige' => 'Se o seu browser n&atilde;o est&aacute; redireccionado, clique aqui para continuar.',
'numero' => 'Number', # NEW

// O
'occurence' => 'Instance', # NEW
'onglet_affacer_base' => 'Apagar a base',
'onglet_auteur' => 'O autor',
'onglet_contenu_site' => 'Conte&uacute;do do s&iacute;tio',
'onglet_evolution_visite_mod' => 'Evolu&ccedil;&atilde;o',
'onglet_fonctions_avances' => 'Fun&ccedil;&otilde;es avan&ccedil;adas',
'onglet_informations_personnelles' => 'Informa&ccedil;&otilde;es pessoais',
'onglet_interactivite' => 'Interactividade',
'onglet_messagerie' => 'Correio',
'onglet_messages_internes' => 'Mensagens internas',
'onglet_messages_publics' => 'Mensagens p&uacute;blicas',
'onglet_messages_vide' => 'Mensagens sem texto',
'onglet_origine_visites' => 'Origem das visitas',
'onglet_repartition_debut' => 'desde o in&iacute;cio',
'onglet_repartition_lang' => 'Distribui&ccedil;&atilde;o por l&iacute;nguas',
'onglet_repartition_rubrique' => 'Distribui&ccedil;&atilde;o das rubricas',
'onglet_save_restaur_base' => 'Salvaguardar/restaurar a base',
'onglet_vider_cache' => 'Esvaziar a cache',
'ortho_trop_de_fautes2' => 'Comece por corrigir os erros mais &oacute;bvios e tente novamente.',

// P
'pass_choix_pass' => 'Favor escolher a sua nova palavra-passe',
'pass_erreur' => 'Erro',
'pass_erreur_acces_refuse' => '<b>Erro :</b> j&aacute; n&atilde;o tem acesso a este s&iacute;tio.',
'pass_erreur_code_inconnu' => '<b>Erro :</b> este c&oacute;digo n&atilde;o corresponde a nenhum dos visitantes com acesso a este s&iacute;tio.',
'pass_erreur_non_enregistre' => '<b>Erro :</b> o endere&ccedil;o <tt>@email_oubli@</tt> n&atilde;o est&aacute; registado neste s&iacute;tio. ',
'pass_erreur_non_valide' => '<b>Erro :</b> este email <tt>@email_oubli@</tt> n&atilde;o &eacute; v&aacute;lido !  ',
'pass_erreur_probleme_technique' => '<b>Erro :</b> por causa de um problema t&eacute;cnico, o email n&atilde;o pode ser enviado.',
'pass_espace_prive_bla' => 'O espa&ccedil;o privado deste s&iacute;tio est&aacute; aberto aos
 visitantes, ap&oacute;s inscri&ccedil;&atilde;o. Uma vez registado poder&aacute; consultar os artigos em curso de redac&ccedil;&atilde;o,
propor artigos e participar em todos os f&oacute;runs.',
'pass_forum_bla' => 'Pediu para intervir num f&oacute;rum
 reservado aos visitadores registados.',
'pass_indiquez_cidessous' => 'Indique abaixo o endere&ccedil;o email sob o qual se registou. Receber&aacute;
 um mail que indicar&aacute; o procedimento a seguir para
        recuperar o seu acesso.',
'pass_mail_passcookie' => '(esta &eacute; uma mensagem autom&aacute;tica)
Para reencontrar o seu acesso ao s&iacute;tio
@nom_site_spip@ (@adresse_site@)

Favor ir ao seguinte endere&ccedil;o :

    @sendcookie@

Poder&aacute; ent&atilde;o introduzir uma nova palavra-passe
 e reconectar-se ao s&iacute;tio.

', # MODIF
'pass_mot_oublie' => 'Palavra-passe esquecida',
'pass_nouveau_enregistre' => 'A sua nova palavra-passe foi registada',
'pass_nouveau_pass' => 'Nova palavra-passe',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Esquecida a palavra-passe',
'pass_quitter_fenetre' => 'Deixar esta janela',
'pass_rappel_login' => 'Recorde : o seu identificador (login) &eacute; &laquo; @login@ &raquo;.',
'pass_recevoir_mail' => 'Vai receber um email que indica como recuperar o seu acesso ao s&iacute;tio.',
'pass_retour_public' => 'Regresso ao s&iacute;tio p&uacute;blico',
'pass_rien_a_faire_ici' => 'Nada a fazer aqui.',
'pass_vousinscrire' => 'Inscrever-se neste s&iacute;tio',
'precedent' => 'precedente',
'previsualisation' => 'Visualiza&ccedil;&atilde;o',
'previsualiser' => 'Visualizar',

// R
'retour' => 'Return', # NEW

// S
'spip_conforme_dtd' => 'SPIP finds this page to be in compliance with its DOCTYPE:', # NEW
'squelette' => 'template', # NEW
'squelette_inclus_ligne' => 'included template, line', # NEW
'squelette_ligne' => 'template, line', # NEW
'stats_visites_et_popularite' => '@visites@ visitas&nbsp;; popularidade&nbsp;: @popularite@',
'suivant' => 'seguinte',

// T
'taille_ko' => '@taille@&nbsp;kb',
'taille_mo' => '@taille@&nbsp;Mb',
'taille_octets' => ' @taille@&nbsp;bytes',
'texte_actualite_site_1' => 'Quando estiver familiarizado(a) com a interface, poder&aacute; clicar sobre &laquo;',
'texte_actualite_site_2' => 'interface completa',
'texte_actualite_site_3' => '&raquo; para abrir mais possibilidades.',
'texte_creation_automatique_vignette' => 'A cria&ccedil;&atilde;o autom&aacute;tica de vinhetas de previsualiza&ccedil;&atilde;o est&aacute; activada neste s&iacute;tio. Se instalar a partir deste formul&aacute;rio imagens de formato(s) @gd_formats@, ser&atilde;o acompanhadas de uma vinheta de um tamanho m&aacute;ximo de @taille_preview@&nbsp;pixels.',
'texte_documents_associes' => 'Os documentos seguintes est&atilde;o associados ao artigo,
  mas n&atilde;o foram directamente
 inseridos nele. Conforme a pagina&ccedil;&atilde;o do s&iacute;tio p&uacute;blico,
  poder&atilde;o aparecer sob forma de documentos anexados.',
'texte_erreur_mise_niveau_base' => 'Erro de base de dados por ocasi&atilde;o do nivelamento.
   A imagem <b>@fichier@</b> n&atilde;o passou (artigo @id_article@).
  Notar bem esta refer&ecirc;ncia, voltar a tentar o nivelamento
, e enfim verificar que as imagens aparecem
 sempre nos artigos.', # MODIF
'texte_erreur_visiteur' => 'You have tried to enter the private area using a login which does not permit this.', # NEW
'texte_inc_auth_1' => 'Voc&ecirc; est&aacute; identificado sob o
   login <b>@auth_login@</b>, mas este j&aacute;/ n&atilde;o existe na base.
 Tente', # MODIF
'texte_inc_auth_2' => 'refazer a liga&ccedil;&atilde;o',
'texte_inc_auth_3' => ', depois de eventualmente ter fechado e
 voltado a abrir o seu navegador.',
'texte_inc_config' => 'As modifica&ccedil;&otilde;es efectuadas nestas p&aacute;ginas influenciam muito o
 funcionamento do seu s&iacute;tio. Recomendamos que n&atilde;o intervenha enquanto n&atilde;o estiver familiarizado com o funcionamento do sistema SPIP. <br /><br /><b>Em
 geral, &eacute; fortemente recomendado
 deixar a responsabilidade dessas p&aacute;ginas ao webmestre principal do seu s&iacute;tio. <b>', # MODIF
'texte_inc_meta_1' => 'O sistema encontrou um erro durante a escrita do arquivo <code>@fichier@</code>. Como administrador do site, queira por favor,', # MODIF
'texte_inc_meta_2' => 'verificar os direitos de escrita',
'texte_inc_meta_3' => 'no direct&oacute;rio <code>@repertoire@</code>.', # MODIF
'texte_statut_en_cours_redaction' => 'em curso de reda&ccedil;&atilde;o',
'texte_statut_poubelle' => 'no caixote de lixo',
'texte_statut_propose_evaluation' => 'proposto para avalia&ccedil;&atilde;o',
'texte_statut_publie' => 'publicado em linha',
'texte_statut_refuse' => 'recusado',
'titre_ajouter_mot_cle' => 'ACRESCENTAR UMA PALAVRA-CHAVE',
'titre_breve_proposee' => 'Not&iacute;cia proposta',
'titre_breve_publiee' => 'Not&iacute;cia publicada',
'titre_breve_refusee' => 'Not&iacute;cia recusada',
'titre_cadre_raccourcis' => 'ATALHOS :',
'titre_changer_couleur_interface' => 'Mudar a cor da interface',
'titre_forum' => 'F&oacute;rum',
'titre_image_admin_article' => 'Pode administrar este artigo',
'titre_image_administrateur' => 'Administrador',
'titre_image_aide' => 'Ajuda sobre este elemento',
'titre_image_auteur_supprime' => 'Autor suprimido',
'titre_image_redacteur' => 'Redactor sem acesso',
'titre_image_redacteur_02' => 'Redactor',
'titre_image_visiteur' => 'Visitante',
'titre_joindre_document' => 'ANEXAR UM DOCUMENTO',
'titre_liens_entrants' => 'Links de entrada',
'titre_mots_cles' => 'PALAVRAS-CHAVE',
'titre_probleme_technique' => 'Aten&ccedil;&atilde;o&nbsp;: um problema t&eacute;cnico (servidor SQL) impede o acesso a esta parte do s&iacute;tio. Obrigado pela sua compreens&atilde;o.', # MODIF
'titre_publier_document' => 'PUBLICAR UM DOCUMENTO NESTA RUBRICA',
'titre_signatures_attente' => 'Signatures awaiting validation', # NEW
'titre_signatures_confirmees' => 'Confirmed signatures', # NEW
'titre_statistiques' => 'Estat&iacute;sticas do s&iacute;tio',
'titre_titre_document' => 'T&iacute;tulo do documento&nbsp;:',
'todo' => 'to come', # NEW
'trad_reference' => '(artigo de refer&ecirc;ncia)',

// Z
'zbug_balise_b_aval' => ': tag B colocada ap&oacute;s BOUCLE',
'zbug_balise_inexistante' => 'erreur @from@: la balise #@balise@ n\'existe pas', # MODIF
'zbug_balise_sans_argument' => 'Missing argument in the @balise@ tag', # NEW
'zbug_boucle' => 'la&ccedil;o',
'zbug_boucle_recursive_undef' => 'la&ccedil;o recursivo n&atilde;o definido', # MODIF
'zbug_calcul' => 'calculation', # NEW
'zbug_champ_hors_boucle' => 'Campo @champ@ fora do la&ccedil;o',
'zbug_champ_hors_motif' => 'Campo @champ@ fora de um la&ccedil;o de motivo @motif@', # MODIF
'zbug_code' => 'c&oacute;digo',
'zbug_critere_inconnu' => 'crit&eacute;rio @critere@ desconhecido', # MODIF
'zbug_distant_interdit' => 'externa interdita', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'doublons sur une table sans clef primaire atomique', # MODIF
'zbug_doublon_table_sans_index' => 'doublons sur une table sans index', # MODIF
'zbug_erreur_boucle_double' => 'BOUCLE@id@: Dupla Defini&ccedil;&atilde;o ', # MODIF
'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: tag final em falta   ', # MODIF
'zbug_erreur_boucle_syntaxe' => 'Loop com sintaxe incorrecta', # MODIF
'zbug_erreur_compilation' => 'Compilation error', # NEW
'zbug_erreur_execution_page' => 'erro de execu&ccedil;&atilde;o da p&aacute;gina', # MODIF
'zbug_erreur_filtre' => 'Erro : filtro <b>&laquo; @filtre@ &raquo;</b> indefinido', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} aplica-se exclusivamente aos links (FORUMS) ou (RUBRIQUES)', # MODIF
'zbug_erreur_squelette' => 'Erro(s) no gabarito',
'zbug_hors_compilation' => 'Uncompiled', # NEW
'zbug_info_erreur_squelette' => 'Erro no s&iacute;tio',
'zbug_inversion_ordre_inexistant' => 'invers&atilde;o de uma ordem inexistente', # MODIF
'zbug_pagination_sans_critere' => '#PAGINATION sans crit&egrave;re {pagination} ou employ&eacute; dans une boucle recursive', # MODIF
'zbug_parametres_inclus_incorrects' => 'Par&acirc;metros de inclus&atilde;o incorrectos', # MODIF
'zbug_profile' => 'Calculation time: @time@', # NEW
'zbug_resultat' => 'resultado',
'zbug_serveur_indefini' => 'sevidor SQL n&atilde;o definido', # MODIF
'zbug_statistiques' => 'SQL query statistics in order of duration', # NEW
'zbug_table_inconnue' => 'Tabela SQL &laquo;@table@&raquo; desconhecida',
'zxml_connus_attributs' => 'known attributes', # NEW
'zxml_de' => 'from', # NEW
'zxml_inconnu_attribut' => 'unknown attribute', # NEW
'zxml_inconnu_balise' => 'unknown tag', # NEW
'zxml_inconnu_entite' => 'unknown entity', # NEW
'zxml_inconnu_id' => 'unknown ID', # NEW
'zxml_mais_de' => 'but from', # NEW
'zxml_non_conforme' => 'not true to the principle', # NEW
'zxml_non_fils' => 'is not a child of', # NEW
'zxml_nonvide_balise' => 'tag not empty', # NEW
'zxml_obligatoire_attribut' => 'required attribute absent in', # NEW
'zxml_succession_fils_incorrecte' => 'incorrect child inheritance', # NEW
'zxml_survoler' => 'to see the correct ones, hover with the cursor', # NEW
'zxml_valeur_attribut' => 'attribute value', # NEW
'zxml_vide_balise' => 'empty tag', # NEW
'zxml_vu' => 'seen before', # NE
);

?>
